"""Main module."""


def ingredients(count):
    """Prints ingredients for making `count` arepas.
    F-string of original code"""
    print(f'{count*0.1} cups arepa flour')
    print(f'{count*0.1} cups cheese')
    print(f'{count*0.025} cups water')
